@@ -5,6 +5,7 @@ MongoDB Module for accessing MongoDB Atlas server via AWS IAM.
 
 from urllib.parse import quote_plus
 from pymongo import MongoClient
+from datetime import datetime
 
 
 class Mongo:
@@ -59,6 +60,11 @@ class Mongo:
 
     def insert_items(self, database, collection, queries):
         try:
+            # Modify queries to add created_at and updated_at
+            for query in queries:
+                query["created_at"] = datetime.today()
+                query["updated_at"] = datetime.today()
+
             writer = self.client[database][collection]
             result = writer.insert_many(queries)
             print(
@@ -70,6 +76,10 @@ class Mongo:
 
     def insert_item(self, database, collection, query):
         try:
+            # Add datetime
+            query["created_at"] = datetime.today()
+            query["updated_at"] = datetime.today()
+
             writer = self.client[database][collection]
             result = writer.insert_one(query)
             print(f"Successfully inserted document to '{database}'-'{collection}'")
@@ -89,6 +99,7 @@ class Mongo:
 
     def update_item(self, database, collection, id, value):
         try:
+            value["updated_at"] = datetime.today()
             selected_collection = self.client[database][collection]
             selected_collection.update_one({"_id": id}, {"$set": value})
         except Exception as err:
